SignaturePadController class

Inheritance

Constructors

SignaturePadController()

Properties

canvasSize Size
Size of the capture surface in logical pixels. This reflects the dimensions provided to the accompanying SignaturePad and can differ from the PDF field size declared in the builder (measured in points).
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
hasSignature bool
no setter
isEmpty bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokes List<List<Offset>>
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clear() → void
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
snapshot() PdfSignatureData
Captures the current strokes and drawing surface into a PdfSignatureData.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited